==> 0.16.0.tar.gz: test/directives/document_title_test.dart <==
import 'dart:html' as dom;
import 'package:angular/angular.dart';
import 'package:angular_test/angular_test.dart';
import 'package:ngx_core/ngx_core.dart';
import 'package:test/test.dart';
import 'document_title_test.template.dart' as self;

/// The test component.
@Component(
    directives: [ngxDirectives],
    providers: [ngxProviders],
    selector: 'test-component',
    template:
        '<div #directive="documentTitle" [documentTitle]="documentTitle" [appendAppName]="appendAppName">{{innerText}}</div>')
class TestComponent {
  TestComponent(this.app);
  final Application app;
  bool appendAppName = false;
  @ViewChild('directive')
  DocumentTitle directive;
  String documentTitle = '';
  String innerText = '';
}

/// Tests the features of the [DocumentTitle] class.
void main() => group('DocumentTitle', () {
      final testBed =
          NgTestBed.forComponent<TestComponent>(self.TestComponentNgFactory);
      tearDown(disposeAnyRunningTest);

      group('.appendAppName', () {
        test('should not append the application name to the document title',
            () async {
          final fixture = await testBed.create();
          await fixture.update((c) => c
            ..appendAppName = false
            ..documentTitle = 'Foo Bar');

          final component = fixture.assertOnlyInstance;
          expect(component.directive.text, component.documentTitle);
          expect(dom.document.title, component.directive.text);
        });

        test('should append the application name to the document title',
            () async {
          final fixture = await testBed.create();
          await fixture.update((c) => c
            ..appendAppName = true
            ..documentTitle = 'Baz Qux');

          final component = fixture.assertOnlyInstance;
          expect(component.directive.text, component.documentTitle);
          expect(dom.document.title,
              '${component.directive.text} | ${component.app.name}');
        });
      });

      group('.ngAfterViewChecked()', () {
        test('should take the inner text of the element if the input is empty',
            () async {
          final fixture = await testBed.create();
          await fixture.update((c) => c
            ..appendAppName = false
            ..innerText = 'Foo Bar Baz');

          final component = fixture.assertOnlyInstance;
          expect(component.directive.text, isEmpty);
          expect(dom.document.title, component.innerText);
        });
      });
    });

==> 0.17.0.tar.gz: test/directives/document_title_test.dart <==
import 'dart:html' as dom;
import 'package:angular/angular.dart';
import 'package:angular_router/testing.dart';
import 'package:angular_test/angular_test.dart';
import 'package:ngx_core/ngx_core.dart';
import 'package:test/test.dart';
import 'document_title_test.template.dart' as self;

/// The test component.
@Component(
    directives: [ngxDirectives],
    providers: [ngxProviders, routerProvidersTest],
    selector: 'test-component',
    template:
        '<div #directive="documentTitle" [documentTitle]="documentTitle" [appendAppName]="appendAppName">{{innerText}}</div>')
class TestComponent {
  TestComponent(this.app);
  final Application app;
  bool appendAppName = false;
  @ViewChild('directive')
  DocumentTitle directive;
  String documentTitle = '';
  String innerText = '';
}

/// Tests the features of the [DocumentTitle] class.
void main() => group('DocumentTitle', () {
      final testBed =
          NgTestBed.forComponent<TestComponent>(self.TestComponentNgFactory);
      tearDown(disposeAnyRunningTest);

      group('.appendAppName', () {
        test('should not append the application name to the document title',
            () async {
          final fixture = await testBed.create();
          await fixture.update((c) => c
            ..appendAppName = false
            ..documentTitle = 'Foo Bar');

          final component = fixture.assertOnlyInstance;
          expect(component.directive.text, component.documentTitle);
          expect(dom.document.title, component.directive.text);
        });

        test('should append the application name to the document title',
            () async {
          final fixture = await testBed.create();
          await fixture.update((c) => c
            ..appendAppName = true
            ..documentTitle = 'Baz Qux');

          final component = fixture.assertOnlyInstance;
          expect(component.directive.text, component.documentTitle);
          expect(dom.document.title,
              '${component.directive.text} | ${component.app.name}');
        });
      });

      group('.ngAfterViewChecked()', () {
        test('should take the inner text of the element if the input is empty',
            () async {
          final fixture = await testBed.create();
          await fixture.update((c) => c
            ..appendAppName = false
            ..innerText = 'Foo Bar Baz');

          final component = fixture.assertOnlyInstance;
          expect(component.directive.text, isEmpty);
          expect(dom.document.title, component.innerText);
        });
      });
    });
